define(function(require) {
    'use strict';

    const storeName = 'imageVaultStore';

    const appInfo = require('appInfo');
    const storage = require('storage');
    const portletContextUtil = require('PortletContextUtil');
    const properties = require('Properties');
    const i18n = require('i18n');

    /**
     * Gets the translated texts used for the client side components
     */
    function getI18n() {
        var texts = {};
        var keys = [
            "order-by-match",
            "done",
            "you-must-supply-the-url-to-the-imagevault-service",
            "unsupported-imagevault-service-located-at",
            "imagevault-service-verified-version",
            "imagevault-service-does-not-meet-required-version",
            "failed-to-connect-to-imagevault-service",
            "width",
            "height",
            "configuration-is-not-completed",
            "e-001-no-input-named-x-found",
            "e-002-more-than-1-input-named-x-was-found",
            "e-003-failed-to-update-metadata-value",
            "e-004-failed-to-retrieve-metadata-definitions",
            "error-during-initialization",
            "ok",
            "cancel",
            "reload",
            "warning-image-is-scaled-to-fit-the-area",
            "editor-title",
            "editor-load-error",
            "cannot-find-asset-with-id-x",
            "failed-to-update-formats",
            "searching",
            "search-returned-0-results",
            "search-yielded-no-additional-results",
            "displaying-first-x-assets-of-y-hits",
            "error-performing-search",
            "asset-x-selected",
            "no-response-was-received",
            "no-asset-with-id-x-was-found",
            "the-requested-conversion-for-asset-x-could-not-be-retrieved",
            "the-requested-conversion-for-asset-x-has-no-html",
            "name", "vault", "uploaded", "uploaded-by",
            "error-during-validate",
            "license-not-active-at-x",
            "cached-credentials-exists",
            "no-cached-credentials-exists",
            "content-type",
            "pin_client_pin_code_request_no_valid_pin_code",
            "pin_client_poll_pin_failed_async_is_not_supported",
            "pin_client_poll_pin_code_returned_state_x",
            "pin_client_no_access_code_was_returned_from_poll_code_response",
            "pin_client_activation_completed",
            "pin_client_activation_is_required_go_to_x_to_activate",
            "has_expired_agreements",
            "has_soon_expired_agreements",
            "all_agreements_are_valid",
            "select-category",
            "categories",
            "metadata-text-value-required",
            "yes",
            "no",
            "metadata-system-area-of-interest",
            "metadata-system-duration",
            "metadata-system-file-extension",
            "metadata-system-image-width",
            "metadata-system-image-height",
            "metadata-system-file-size",
            "legalBasis",
            "legalBasisAgreement",
            "legalBasisConsent",
            "legalBasisLegalObligation",
            "legalBasisLegitimateInterest",
            "legalBasisProtectRegistrantsVitalInterests",
            "legalBasisPublicInterest"
        ];
        keys.forEach(k => {
            addI18n(texts, k);
        });
        return texts;
    }

    function addI18n(texts, key) {
        var t = i18n.get(key);
        if (!t) return;
        texts[key] = t;
    }

    return {
        setConfig: function(config, callback) {
            var store = storage.getKeyValueDataStore(storeName);
            store.put('config', config, (err, data) => {
                if (err) {
                    callback({ success: false, error: "Error during PUT config: " + JSON.stringify(err) });
                    return;
                }
                callback({ success: true, data: data });
            });

        },
        deleteConfig: function(callback) {
            var store = storage.getKeyValueDataStore(storeName);

            store.remove('config', (err, data) => {
                if (err) {
                    callback({ success: false, error: "Error during DELETE config: " + JSON.stringify(err) });
                    return;
                }
                callback({ success: true });
            });
        },
        getConfig: function(callback) {
            var store = storage.getKeyValueDataStore(storeName);
            var config = {};
            store.get('config', (err, data) => {
                if (!err) {
                    config = data;
                }
                callback(config);
            });
        },
        getSettings: function(callback) {
            this.getConfig((config) => {
                var resourcePath = '/webapp-files/' + appInfo.appIdentifier + '/' + appInfo.appVersion + "/";
                var pageNode = portletContextUtil.getCurrentPage();
                var pageUrl = properties.get(pageNode, 'URL');
                var pageName = properties.get(pageNode, 'displayName');
                var uiLang = i18n.get("uilang");
                var openIvUrl = config.ivUrl + "?uilang=" + uiLang;
                callback({
                    config: config,
                    openIvUrl: openIvUrl,
                    appInfo: appInfo,
                    resourcePath: resourcePath,
                    i18n: getI18n(),
                    uiLang: uiLang,
                    pageInfo: {
                        url: pageUrl,
                        name: pageName
                    }
                });
            });
        }
    }
});